@@ -855,7 +855,13 @@ sub _set ($ $ $) {
         $self->_validate( $key, $value, @{ $vf->{$key} } );
     }
 
-    if ( ref $vf->{$key}[0] eq 'ARRAY' && defined($value) && $value =~ /,/ ) {
+    # Nagios allows the usage of a '+' sign. This breaks member lists.
+    # Ignore the '+' sign completely for now.
+    if ( ref $vf->{$key}[0] eq 'ARRAY' && $value =~/^\+(.+)$/ ) {
+        $value = $1;
+    }
+
+    if ( ref $vf->{$key}[0] eq 'ARRAY' && $value =~ /,/ ) {
         $value = [ split /\s*,\s*/, $value ];
     }
 
